FlutterTencentBuglyConfig class

公共配置项

Constructors

FlutterTencentBuglyConfig({bool isDebugMode = kDebugMode, bool isDevelopmentDevice = false, String? channel, String? version, String? deviceId})
const

Properties

channel → String?
渠道
final
deviceId → String?
设备唯一标识
final
hashCode → int
The hash code for this object.
no setterinherited
isDebugMode → bool
SDK Debug信息开关, 默认关闭
final
isDevelopmentDevice → bool
是否开发设备, 默认关闭
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String?
版本号
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
参数
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited