FlutterTencentBuglyIOSConfig class

iOS 配置项

Inheritance

Constructors

FlutterTencentBuglyIOSConfig({required String appId, bool blockMonitorEnable = true, int blockMonitorTimeout = 3, bool symbolicateInProcessEnable = true, bool unexpectedTerminatingDetectionEnable = true, bool viewControllerTrackingEnable = true, int reportLogLevel = 0})
const

Properties

appId → String
注册产品时申请的 AppID
finalinherited
blockMonitorEnable → bool
卡顿监控开关,默认开启
final
blockMonitorTimeout → int
卡顿监控判断间隔,单位为秒
final
hashCode → int
The hash code for this object.
no setterinherited
reportLogLevel → int
控制自定义日志上报,默认值为 BuglyLogLevelSilent,即关闭日志记录功能。 如果设置为 BuglyLogLevelWarn,则在崩溃时会上报Warn、Error接口打印的日志
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbolicateInProcessEnable → bool
进程内还原开关,默认开启
final
unexpectedTerminatingDetectionEnable → bool
非正常退出事件记录开关,默认开启
final
viewControllerTrackingEnable → bool
页面信息记录开关,默认开启
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
参数
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited