methodChannel property
The method channel used to interact with the native platform.
Implementation
@visibleForTesting
final MethodChannel methodChannel = const MethodChannel('flutter_tencent_bugly');
The method channel used to interact with the native platform.
@visibleForTesting
final MethodChannel methodChannel = const MethodChannel('flutter_tencent_bugly');