FlutterTencentBuglyPlatform class
abstract
- Inheritance
-
- Object
- PlatformInterface
- FlutterTencentBuglyPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion()
→ Future<String?>
-
-
init({FlutterTencentBuglyConfig? config, FlutterTencentBuglyAndroidConfig? android, FlutterTencentBuglyIOSConfig? ios})
→ Future<bool>
-
初始化腾讯 Bugly。
-
log({required String tag, required String message, LogLevel level = .INFO})
→ Future<void>
-
输出 Bugly 日志,发生 Crash 时随之上报
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
postException({required dynamic message, required dynamic detail, dynamic type, })
→ Future<void>
-
上报自定义异常
-
putUserData({required String key, required String value})
→ Future<void>
-
设置自定义的 Key-Value 数据,发生 Crash 时随之上报
-
runGuarded<T>(ValueGetter<T> body, {FlutterExceptionHandler? onException, String? filterPattern, bool reportInDebugMode = false})
→ void
-
异常上报。该方法等同于 runZonedGuarded。
-
setChannel(String value)
→ Future<void>
-
设置渠道
-
setDeviceID(String value)
→ Future<void>
-
设置设备ID
-
setDeviceModel(String value)
→ Future<void>
-
设置设备型号
-
setPackageName(String value)
→ Future<void>
-
设置包名
-
setUserId(String value)
→ Future<void>
-
设置用户ID
-
setUserTag(int value)
→ Future<void>
-
设置标签
-
setVersion(String value)
→ Future<void>
-
设置版本号
-
toString()
→ String
-
A string representation of this object.
inherited