MethodChannelFlutterTencentBugly class
An implementation of FlutterTencentBuglyPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlutterTencentBuglyPlatform
- MethodChannelFlutterTencentBugly
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
override
-
init(
{FlutterTencentBuglyConfig? config, FlutterTencentBuglyAndroidConfig? android, FlutterTencentBuglyIOSConfig? ios}) → Future< bool> -
初始化腾讯 Bugly。
override
-
log(
{required String tag, required String message, LogLevel level = .INFO}) → Future< void> -
输出 Bugly 日志,发生 Crash 时随之上报
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postException(
{required dynamic message, required dynamic detail, dynamic type, Map< String, dynamic> ? extra}) → Future<void> -
上报自定义异常
override
-
putUserData(
{required String key, required String value}) → Future< void> -
设置自定义的 Key-Value 数据,发生 Crash 时随之上报
override
-
runGuarded<
T> (ValueGetter< T> body, {FlutterExceptionHandler? onException, String? filterPattern, bool reportInDebugMode = false}) → void -
异常上报。该方法等同于 runZonedGuarded。
override
-
setChannel(
String value) → Future< void> -
设置渠道
override
-
setDeviceID(
String value) → Future< void> -
设置设备ID
override
-
setDeviceModel(
String value) → Future< void> -
设置设备型号
override
-
setPackageName(
String value) → Future< void> -
设置包名
override
-
setUserId(
String value) → Future< void> -
设置用户ID
override
-
setUserTag(
int value) → Future< void> -
设置标签
override
-
setVersion(
String value) → Future< void> -
设置版本号
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited